@@ -52,11 +52,11 @@ protected:
     virtual void paintContact(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const = 0;
     /** The size hint for painting contact items*/
     virtual QSize sizeHintContact(const QStyleOptionViewItem &option, const QModelIndex &index) const = 0;
+    virtual QSize sizeHintHeader(const QStyleOptionViewItem &option, const QModelIndex &index) const;
 
 private:
     /** Paints header items*/
     void paintHeader(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
-    QSize sizeHintHeader(const QStyleOptionViewItem &option, const QModelIndex &index) const;
 };
 
 #endif // ABSTRACT_CONTACT_DELEGATE_H
